@@ -1,7 +1,6 @@
 from nonebot.rule import T_State
-from nonebot import on_message, get_driver
-from nonebot.adapters.onebot.v11 import Bot, GroupMessageEvent, Message
-import re
+from nonebot import get_driver
+from nonebot.adapters.onebot.v11 import Bot, GroupMessageEvent, MessageSegment
 from .config import Config
 from .data_source import get_github_reposity_information
 from nonebot.plugin import on_regex
@@ -15,4 +14,4 @@ async def github_handle(bot: Bot, event: GroupMessageEvent, state: T_State):
     url = event.get_plaintext()
     imageUrl = await get_github_reposity_information(url)
     assert(imageUrl != "获取信息失败")
-    await github.send(Message(f"[CQ:image,file={imageUrl}]"))
\ No newline at end of file
+    await github.send(MessageSegment.image(imageUrl))
\ No newline at end of file
